pub struct TimestampStyleConversionError { /* private fields */ }Expand description
Converting a TimestampStyle from a string slice failed.
Implementations
Sourceimpl TimestampStyleConversionError
impl TimestampStyleConversionError
Sourcepub const fn kind(&self) -> &TimestampStyleConversionErrorType
pub const fn kind(&self) -> &TimestampStyleConversionErrorType
Immutable reference to the type of error that occurred.
Sourcepub fn into_parts(
self,
) -> (TimestampStyleConversionErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts( self, ) -> (TimestampStyleConversionErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.